package com.cj.jiaqingjiayi.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.cj.jiaqingjiayi.common.BaseResponse;
import com.cj.jiaqingjiayi.common.ErrorCode;
import com.cj.jiaqingjiayi.common.ResultUtils;
import com.cj.jiaqingjiayi.exception.BusinessException;
import com.cj.jiaqingjiayi.exception.ThrowUtils;
import com.cj.jiaqingjiayi.model.domain.*;
import com.cj.jiaqingjiayi.model.request.manicurist.*;
import com.cj.jiaqingjiayi.model.vo.ManicuristVO;
import com.cj.jiaqingjiayi.service.ManicuristService;
import com.cj.jiaqingjiayi.service.UserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.DigestUtils;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import java.util.List;

import static com.cj.jiaqingjiayi.contant.UserConstant.USER_SALT;

@RestController
@Slf4j
@Api(tags = "美甲师接口")
@RequestMapping("/manicurist")
public class ManicuristController {

    @Resource
    private ManicuristService manicuristService;

    @Resource
    private UserService userService;


    /**
     * 添加美甲师(管理员)
     * @param adminManicuristAddRequest
     * @return
     */
    @ApiOperation(value = "管理员添加美甲师")
    @PostMapping("/adminAdd")
    @Transactional(rollbackFor = Exception.class)
    public BaseResponse<Long> AdminAddManicurist(@RequestBody AdminManicuristAddRequest adminManicuristAddRequest, HttpServletRequest request) {
        //判断是否为管理员
        userService.isAdmin(request);

        ThrowUtils.throwIf(adminManicuristAddRequest == null, ErrorCode.PARAMS_ERROR);

        User user = new User();
        BeanUtils.copyProperties(adminManicuristAddRequest, user);
        Manicurist manicurist = new Manicurist();
        BeanUtils.copyProperties(adminManicuristAddRequest, manicurist);
        ManicuristAuth manicuristAuth = new ManicuristAuth();
        BeanUtils.copyProperties(adminManicuristAddRequest, manicuristAuth);

        //对每个应该校验的业务进行校验
        manicuristService.validUser(user, true);
        manicuristService.validManicurist(manicurist, true);
        manicuristService.validManicuristAuth(manicuristAuth, true);

        //插入到表中
        manicuristService.adminAddManicurist(user, manicurist, manicuristAuth);

        return ResultUtils.success(manicurist.getId(),"添加美甲师成功");
    }

    /**
     * 认证成为美甲师
     * @param manicuristAddRequest
     * @return
     */
    @ApiOperation(value = "认证美甲师")
    @PostMapping("/add")
    public BaseResponse<Long> addManicurist(@RequestBody ManicuristAddRequest manicuristAddRequest, HttpServletRequest request) {
        ThrowUtils.throwIf(manicuristAddRequest == null, ErrorCode.PARAMS_ERROR);
        //获取登录的用户
        User loginUser = userService.getLoginUser(request);

        Manicurist manicurist = new Manicurist();
        //如果不给美甲师名字默认为用户名字
        if (manicuristAddRequest.getManicuristName() == null) {
            manicuristAddRequest.setManicuristName(loginUser.getUsername());
        }
        BeanUtils.copyProperties(manicuristAddRequest, manicurist);
        ManicuristAuth manicuristAuth = new ManicuristAuth();
        BeanUtils.copyProperties(manicuristAddRequest, manicuristAuth);
        manicuristService.validManicurist(manicurist, true);
        manicuristService.validManicuristAuth(manicuristAuth, true);

        //插入到表中
        manicuristService.addManicurist(loginUser, manicurist, manicuristAuth);

        return ResultUtils.success(manicurist.getId(),"添加美甲师成功");
    }

    /**
     * 删除美甲师
     */
    @ApiOperation(value = "删除美甲师")
    @PostMapping("/deleteMan")
    @Transactional(rollbackFor = Exception.class)
    public BaseResponse<Boolean> DeleteManicurist(long id, HttpServletRequest request){
        //判断是否为管理员
        userService.isAdmin(request);

        manicuristService.deleteMan(id);
        return ResultUtils.success(true);
    }

    /**
     * 管理员修改美甲师信息
     * 确认一定会传入美甲师的id？
     */
    @ApiOperation(value = "管理修改美甲师信息")
    @PostMapping("/update")
    public BaseResponse<Boolean> UpdateManicurist(@RequestBody ManicuristUpdateRequest manicuristUpdateRequest, HttpServletRequest request){
        //判断是否为管理员
        userService.isAdmin(request);

        if (manicuristUpdateRequest == null || manicuristUpdateRequest.getId() == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "传入参数为空");
        }

        Manicurist manicurist = new Manicurist();

        if(manicuristUpdateRequest.getBusinessId() != null){
            //检验美甲师绑定的商家是否存在
            manicuristService.validManBus(manicuristUpdateRequest.getBusinessId());
        }

        BeanUtils.copyProperties(manicuristUpdateRequest, manicurist);

        //校验一下
        manicuristService.validManicurist(manicurist, false);

        boolean result = manicuristService.updateById(manicurist);
        ThrowUtils.throwIf(!result, ErrorCode.OPERATION_ERROR);
        return ResultUtils.success(true, "修改成功");
    }

    /**
     *美甲师修改个人信息
     */
    //TODO:后续可能会改
    @ApiOperation(value = "美甲师修改个人信息")
    @PostMapping("/myUpdate")
    public BaseResponse<Boolean> MyUpdateManicurist(@RequestBody MyManicuristUpdateRequest myUpdateRequest, HttpServletRequest request){
        ThrowUtils.throwIf(myUpdateRequest == null, ErrorCode.NULL_ERROR);

        User logingUser = userService.getLoginUser(request);
        Long userId = logingUser.getId();
        QueryWrapper<Manicurist> manicuristQueryWrapper = new QueryWrapper<Manicurist>().eq("userId", userId);

        Manicurist manicuristLog = manicuristService.getOne(manicuristQueryWrapper);
        ThrowUtils.throwIf(manicuristLog == null , ErrorCode.NULL_ERROR);
        Long manId = manicuristLog.getId();

        Manicurist manicurist = new Manicurist();
        manicurist.setId(manId);
        BeanUtils.copyProperties(myUpdateRequest, manicurist);
        manicuristService.validManicurist(manicurist, false);


        boolean result = manicuristService.updateById(manicurist);
        ThrowUtils.throwIf(!result, ErrorCode.OPERATION_ERROR, "修改失败");
        return ResultUtils.success(true, "修改成功");
    }

    /**
     * 根据id查询美甲师(管理员)
     */
    @ApiOperation(value = "根据id获取美甲师")
    @GetMapping("/queryById")
    public BaseResponse<Manicurist> QueryByIdManicurist(@RequestParam Integer manicuristId, HttpServletRequest request){
        userService.isAdmin(request);

        ThrowUtils.throwIf(manicuristId < 0, ErrorCode.NULL_ERROR, "id不符合规范");
        Manicurist manicurist = manicuristService.getById(manicuristId);
        ThrowUtils.throwIf(manicurist == null, ErrorCode.PARAMS_ERROR, "美甲师不存在");

        return ResultUtils.success(manicurist);
    }

    /**
     * 查询全部美甲师（管理员）
     */
    @ApiOperation(value = "查询全部美甲师")
    @PostMapping("/queryAll")
    public BaseResponse<List<Manicurist>> QueryAllManicurist(HttpServletRequest request){
        userService.isAdmin(request);

        List<Manicurist> manicuristList = manicuristService.list();
        return ResultUtils.success(manicuristList);
    }

    /**
     * 查询全部美甲师（用户）
     * 用于展示店铺信息
     */
    @ApiOperation(value = "用户查询全部美甲师")
    @GetMapping("/userQueryAll")
    public BaseResponse<List<ManicuristVO>> UserQueryAllManicurist(@RequestParam Long businessId){

        QueryWrapper<Manicurist> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("businessId", businessId);
        List<Manicurist> manicuristList = manicuristService.list(queryWrapper);
        List<ManicuristVO> manicuristVOList = manicuristService.getManicuristVO(manicuristList);
        return ResultUtils.success(manicuristVOList);
    }

//    /**
//     * 搜索美甲师
//     */
//    @ApiOperation(value = "用户查询美甲师")
//    @PostMapping("/userQuery")
//    public BaseResponse<List<ManicuristVO>> UserQueryManicurist(@RequestBody ManicuristQueryRequest manicuristQueryRequest){
//        ThrowUtils.throwIf(manicuristQueryRequest == null, ErrorCode.NULL_ERROR);
//
//        QueryWrapper<Manicurist> queryWrapper = manicuristService.getQueryWrapper(manicuristQueryRequest);
//
//        List<Manicurist> manicuristList = manicuristService.list(queryWrapper);
//
//        List<ManicuristVO> manicuristVO = manicuristService.getManicuristVO(manicuristList);
//
//        return ResultUtils.success(manicuristVO);
//    }


}
