package com.cj.jiaqingjiayi.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cj.jiaqingjiayi.common.ErrorCode;
import com.cj.jiaqingjiayi.exception.ThrowUtils;
import com.cj.jiaqingjiayi.model.domain.Business;
import com.cj.jiaqingjiayi.model.domain.Collect;
import com.cj.jiaqingjiayi.model.domain.User;
import com.cj.jiaqingjiayi.model.request.collect.CollectAddRequest;
import com.cj.jiaqingjiayi.service.BusinessService;
import com.cj.jiaqingjiayi.service.CollectService;
import com.cj.jiaqingjiayi.mapper.CollectMapper;
import com.cj.jiaqingjiayi.service.UserService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

/**
* @author 高木
* @description 针对表【collect(收藏)】的数据库操作Service实现
* @createDate 2024-12-02 14:11:46
*/
@Service
public class CollectServiceImpl extends ServiceImpl<CollectMapper, Collect>
    implements CollectService{

    @Resource
    private UserService userService;

    @Resource
    private BusinessService businessService;

    @Override
    public void validCollect(CollectAddRequest collectAddRequest) {
        Long businessId = collectAddRequest.getBusinessId();
        ThrowUtils.throwIf(businessId == null, ErrorCode.PARAMS_ERROR, "参数不全");
        LambdaQueryWrapper<Business> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(Business::getId, businessId);
        long count = businessService.count(wrapper);
        ThrowUtils.throwIf(count != 1, ErrorCode.PARAMS_ERROR, "填写的商家id不存在");
    }

    @Override
    public Boolean addCollect(Collect collect, HttpServletRequest request) {
        User loginUser = userService.getLoginUser(request);
        Long loginUserId = loginUser.getId();
        Long businessId = collect.getBusinessId();
        LambdaQueryWrapper<Collect> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(Collect::getBusinessId, businessId);
        wrapper.eq(Collect::getUserId, loginUserId);
        long count = this.count(wrapper);
        ThrowUtils.throwIf(count > 0, ErrorCode.OPERATION_ERROR, "该商家已收藏");
        collect.setUserId(loginUserId);
        return this.save(collect);
    }
}




