package com.cj.jiaqingjiayi.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cj.jiaqingjiayi.common.ErrorCode;
import com.cj.jiaqingjiayi.contant.CommonConstant;
import com.cj.jiaqingjiayi.exception.BusinessException;
import com.cj.jiaqingjiayi.exception.ThrowUtils;
import com.cj.jiaqingjiayi.model.domain.*;
import com.cj.jiaqingjiayi.model.request.manicurist.ManicuristQueryRequest;
import com.cj.jiaqingjiayi.model.vo.ManicuristVO;
import com.cj.jiaqingjiayi.service.*;
import com.cj.jiaqingjiayi.mapper.ManicuristMapper;
import com.cj.jiaqingjiayi.utils.RegexUtils;
import com.cj.jiaqingjiayi.utils.SqlUtils;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.util.DigestUtils;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

import static com.cj.jiaqingjiayi.contant.UserConstant.USER_SALT;

/**
* @author 高木
*/
@Service
public class ManicuristServiceImpl extends ServiceImpl<ManicuristMapper, Manicurist>
    implements ManicuristService{

    @Resource
    private UserService userService;

    @Resource
    private BusinessService businessService;

    @Resource
    private ManicuristAuthService manicuristAuthService;

    //管理员添加美甲师
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void adminAddManicurist(User user, Manicurist manicurist, ManicuristAuth manicuristAuth) {
        //加密
        String encryptPassword = DigestUtils.md5DigestAsHex((USER_SALT + user.getUserPassword()).getBytes());
        user.setUserPassword(encryptPassword);
        //往user表中补充美甲师信息
        user.setUsername(manicurist.getManicuristName());
        user.setAvatarUrl(manicurist.getManicuristAvatar());
        user.setPhone(manicurist.getPhone());

        //更改用户权限为美甲师
        user.setUserRole(3);

        boolean save = userService.save(user);
        ThrowUtils.throwIf(!save, ErrorCode.OPERATION_ERROR, "添加美甲师失败");

        //美甲师绑定user
        manicurist.setUserId(user.getId());
        boolean save1 = this.save(manicurist);
        ThrowUtils.throwIf(!save1, ErrorCode.OPERATION_ERROR, "绑定id失败");
        //添加认证信息
        manicuristAuth.setArtistId(manicurist.getId());
        boolean save2 = manicuristAuthService.save(manicuristAuth);
        ThrowUtils.throwIf(!save2, ErrorCode.OPERATION_ERROR, "添加美甲师认证信息失败");
    }

    //用户注册美甲师
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void addManicurist(User loginUser, Manicurist manicurist, ManicuristAuth manicuristAuth) {
        //美甲师绑定user
        Long userId = loginUser.getId();
        manicurist.setUserId(userId);

        //更改用户权限为美甲师
        loginUser.setUserRole(3);

        //往user表中补充美甲师信息
        loginUser.setUsername(manicurist.getManicuristName());
        loginUser.setAvatarUrl(manicurist.getManicuristAvatar());
        loginUser.setPhone(manicurist.getPhone());

        boolean save = userService.updateById(loginUser);
        ThrowUtils.throwIf(!save, ErrorCode.OPERATION_ERROR, "绑定失败");

        boolean save1 = this.save(manicurist);
        ThrowUtils.throwIf(!save1, ErrorCode.OPERATION_ERROR, "绑定id失败");

        //添加认证信息
        manicuristAuth.setArtistId(manicurist.getId());
        boolean save2 = manicuristAuthService.save(manicuristAuth);
        ThrowUtils.throwIf(!save2, ErrorCode.OPERATION_ERROR, "添加美甲师认证信息失败");
    }

    @Override
    public void validUser(User user, boolean add) {
        ThrowUtils.throwIf(user == null , ErrorCode.NULL_ERROR);

        String userAccount = user.getUserAccount();
        String userPassword = user.getUserPassword();

        if (add) {
            ThrowUtils.throwIf(StringUtils.isAllBlank(userAccount, userPassword), ErrorCode.PARAMS_ERROR);

            if (userAccount.length() < 4) {
                throw new BusinessException(ErrorCode.PARAMS_ERROR, "用户账号不符合要求");
            }

            if(userPassword.length() < 8) {
                throw new BusinessException(ErrorCode.PARAMS_ERROR, "用户密码不符合要求");
            }

            QueryWrapper<User> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("userAccount", userAccount);
            long count = userService.count(queryWrapper);
            if (count > 0) {
                throw new BusinessException(ErrorCode.PARAMS_ERROR, "账号重复");
            }
        }
    }

    @Override
    public void validManicurist(Manicurist manicurist, boolean add) {
        Long id = manicurist.getId();
        String manicuristName = manicurist.getManicuristName();
        String manicuristPhone = manicurist.getPhone();
        Integer gender = manicurist.getGender();

        //只在添加时严格校验 保证商家信息是全的
        if (add) {
            if (StringUtils.isAnyBlank(manicuristName, manicuristPhone) || gender == null) {
                throw new BusinessException(ErrorCode.PARAMS_ERROR, "信息不全");
            }
        }

        if(!add){
            Manicurist byId = this.getById(id);
            ThrowUtils.throwIf(byId == null, ErrorCode.NULL_ERROR, "美甲师不存在");
        }

        if(StringUtils.isNotBlank(manicuristName)){
            QueryWrapper<Manicurist> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("manicuristName", manicuristName);
            long count = this.count(queryWrapper);
            ThrowUtils.throwIf(count > 0, ErrorCode.OPERATION_ERROR, "美甲师名称重复");
        }

        //校验手机号格式
        if (StringUtils.isNotBlank(manicuristPhone)) {
            boolean phoneInvalid = RegexUtils.isPhoneInvalid(manicuristPhone);
            ThrowUtils.throwIf(phoneInvalid, ErrorCode.PARAMS_ERROR, "手机号格式错误");

            QueryWrapper<Manicurist> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("Phone", manicuristPhone);
            long count = this.count(queryWrapper);
            ThrowUtils.throwIf(count > 0 , ErrorCode.OPERATION_ERROR, "手机号重复");
        }
    }

    @Override
    public void validManicuristAuth(ManicuristAuth manicuristAuth, boolean add) {
        //只在添加时严格校验 保证认证信息是全的
        if (add) {
            String certification_number = manicuristAuth.getCertification_number();
            String certificate_path = manicuristAuth.getCertificate_path();
            String issuing_authority = manicuristAuth.getIssuing_authority();
            if (StringUtils.isAnyBlank(certification_number, certificate_path, issuing_authority)) {
                throw new BusinessException(ErrorCode.PARAMS_ERROR, "美甲师认证信息不全");
            }
        }
    }

    @Override
    public void validManBus(Long businessId) {
        Business byId = businessService.getById(businessId);
        ThrowUtils.throwIf(byId == null, ErrorCode.NULL_ERROR, "商家不存在");
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void deleteMan(long id) {
        Manicurist manicurist = this.getById(id);
        ThrowUtils.throwIf(manicurist == null, ErrorCode.OPERATION_ERROR, "删除的美甲师不存在");
        Long userId = manicurist.getUserId();
        User user = userService.getById(userId);
        user.setUserRole(0);
        boolean update = userService.updateById(user);
        ThrowUtils.throwIf(!update, ErrorCode.PARAMS_ERROR, "操作失败");

        boolean result = this.removeById(id);
        ThrowUtils.throwIf(!result, ErrorCode.PARAMS_ERROR, "操作失败");
    }

    @Override
    public ManicuristVO getManicuristVO(Manicurist manicurist) {
        if(manicurist == null ){
            return  null;
        }
        ManicuristVO manicuristVO = new ManicuristVO();
        BeanUtils.copyProperties(manicurist, manicuristVO);
        return manicuristVO;
    }

    @Override
    public List<ManicuristVO> getManicuristVO(List<Manicurist> manicuristList) {
        if(CollectionUtils.isEmpty(manicuristList)){
            return new ArrayList<>();
        }
        return manicuristList.stream().map(this::getManicuristVO).collect(Collectors.toList());
    }

//    @Override
//    public QueryWrapper<Manicurist> getQueryWrapper(ManicuristQueryRequest manicuristQueryRequest) {
//        if (manicuristQueryRequest == null) {
//            throw new BusinessException(ErrorCode.PARAMS_ERROR, "请求参数为空");
//        }
//
//
//        Long id = manicuristQueryRequest.getId();
//        Long userId = manicuristQueryRequest.getUserId();
//        Long businessId = manicuristQueryRequest.getBusinessId();
//        String manicuristName = manicuristQueryRequest.getManicuristName();
//        Integer gender = manicuristQueryRequest.getGender();
//        String Phone = manicuristQueryRequest.getPhone();
//        String email = manicuristQueryRequest.getEmail();
//        Date employment_date = manicuristQueryRequest.getEmployment_date();
//        String specialties = manicuristQueryRequest.getSpecialties();
//        BigDecimal rating = manicuristQueryRequest.getRating();
//        BigDecimal salary = manicuristQueryRequest.getSalary();
//
//
//        QueryWrapper<Manicurist> queryWrapper = new QueryWrapper<>();
//        if (ObjectUtils.isNotEmpty(id)) {
//            queryWrapper.eq("id", id);
//        }
//
//        if (ObjectUtils.isNotEmpty(userId)) {
//            queryWrapper.eq("userId", userId);
//        }
//
//        if (ObjectUtils.isNotEmpty(businessId)) {
//            queryWrapper.eq("businessId", businessId);
//        }
//
//        if (ObjectUtils.isNotEmpty(manicuristName)) {
//            queryWrapper.eq("manicuristName", manicuristName);
//        }
//
//        if (ObjectUtils.isNotEmpty(gender)) {
//            queryWrapper.eq( "gender", gender);
//        }
//
//        if (ObjectUtils.isNotEmpty(Phone)) {
//            queryWrapper.eq( "Phone", Phone);
//        }
//
//        if (ObjectUtils.isNotEmpty(email)) {
//            queryWrapper.eq( "email", email);
//        }
//
//        if (ObjectUtils.isNotEmpty(employment_date)) {
//            queryWrapper.like( "employment_date", employment_date);
//        }
//
//        if (ObjectUtils.isNotEmpty(specialties)) {
//            queryWrapper.like( "specialties", specialties);
//        }
//
//        if (ObjectUtils.isNotEmpty(rating)) {
//            queryWrapper.like( "rating", rating);
//        }
//
//        if (ObjectUtils.isNotEmpty(salary)) {
//            queryWrapper.like( "salary", salary);
//        }
//
//        String sortField = manicuristQueryRequest.getSortField();
//        String sortOrder = manicuristQueryRequest.getSortOrder();
//        queryWrapper.orderBy(SqlUtils.validSortField(sortField), sortOrder.equals(CommonConstant.SORT_ORDER_ASC),
//                sortField);
//
//        return queryWrapper;
//    }
}




